@@ -507,3 +507,7 @@ class Dumper(DumperBase):
 
     def putCallItem(self, name, rettype, value, func, *args):
         return
+
+    def symbolAddress(self, symbolName):
+        res = self.nativeParseAndEvaluate(symbolName)
+        return None if res is None else res.address()
